from distutils.core import setup

setup(
    name='nlknhjc',
    version='1.2.0',
    py_modules= ['nlknhjc'],
    author='knhjc',
    author_email='rbshuangjinchao@163.com',
    url='http://www.baidu.com',
    description='A simple printer of nested lists',
)